==> apache-camel-2.25.4-src.zip: apache-camel-2.25.4/components/camel-jsonpath/src/test/java/org/apache/camel/jsonpath/JsonPathTransformResultTypeTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.jsonpath;

import java.io.File;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.test.junit4.CamelTestSupport;
import org.junit.Test;

public class JsonPathTransformResultTypeTest extends CamelTestSupport {

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("direct:start")
                    .transform().jsonpath("$.store.book[0].price", Float.class)
                    .to("mock:price");

                from("direct:second")
                    .transform().jsonpath("$.store.book[0].price", Double.class)
                    .to("mock:price");
            }
        };
    }

    @Test
    public void testPriceResultType() throws Exception {
        getMockEndpoint("mock:price").expectedMessageCount(4);
        getMockEndpoint("mock:price").message(0).body().isInstanceOf(Float.class);
        getMockEndpoint("mock:price").message(1).body().isInstanceOf(Double.class);
        getMockEndpoint("mock:price").message(2).body().isInstanceOf(Float.class);
        getMockEndpoint("mock:price").message(3).body().isInstanceOf(Double.class);

        template.sendBody("direct:start", new File("src/test/resources/books.json"));
        template.sendBody("direct:second", new File("src/test/resources/books.json"));
        template.sendBody("direct:start", new File("src/test/resources/books.json"));
        template.sendBody("direct:second", new File("src/test/resources/books.json"));

        assertMockEndpointsSatisfied();
    }

}

==> apache-camel-3.4.2-src.zip: apache-camel-3.4.2/components/camel-jsonpath/src/test/java/org/apache/camel/jsonpath/JsonPathTransformResultTypeTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.jsonpath;

import java.io.File;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.Test;

public class JsonPathTransformResultTypeTest extends CamelTestSupport {

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("direct:start")
                    .transform().jsonpath("$.store.book[0].price", Float.class)
                    .to("mock:price");

                from("direct:second")
                    .transform().jsonpath("$.store.book[0].price", Double.class)
                    .to("mock:price");
            }
        };
    }

    @Test
    public void testPriceResultType() throws Exception {
        getMockEndpoint("mock:price").expectedMessageCount(4);
        getMockEndpoint("mock:price").message(0).body().isInstanceOf(Float.class);
        getMockEndpoint("mock:price").message(1).body().isInstanceOf(Double.class);
        getMockEndpoint("mock:price").message(2).body().isInstanceOf(Float.class);
        getMockEndpoint("mock:price").message(3).body().isInstanceOf(Double.class);

        template.sendBody("direct:start", new File("src/test/resources/books.json"));
        template.sendBody("direct:second", new File("src/test/resources/books.json"));
        template.sendBody("direct:start", new File("src/test/resources/books.json"));
        template.sendBody("direct:second", new File("src/test/resources/books.json"));

        assertMockEndpointsSatisfied();
    }

}
